"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function sourcesFromPostmanCollection(collectionJSON) {
    var collection = Convert.toPostmanCollection(collectionJSON);
    return collection.item.map(function (item) { return ({ name: item.name, samples: item.response.map(function (r) { return r.body; }) }); });
}
exports.sourcesFromPostmanCollection = sourcesFromPostmanCollection;
// Converts JSON strings to/from your types
// and asserts the results of JSON.parse at runtime
var Convert;
(function (Convert) {
    function toPostmanCollection(json) {
        return cast(JSON.parse(json), O("PostmanCollection"));
    }
    Convert.toPostmanCollection = toPostmanCollection;
    function postmanCollectionToJson(value) {
        return JSON.stringify(value, null, 2);
    }
    Convert.postmanCollectionToJson = postmanCollectionToJson;
    function cast(obj, typ) {
        if (!isValid(typ, obj)) {
            throw "Invalid value";
        }
        return obj;
    }
    function isValid(typ, val) {
        if (typ === undefined)
            return true;
        if (typ === null)
            return val === null || val === undefined;
        return typ.isUnion ? isValidUnion(typ.typs, val)
            : typ.isArray ? isValidArray(typ.typ, val)
                : typ.isMap ? isValidMap(typ.typ, val)
                    : typ.isEnum ? isValidEnum(typ.name, val)
                        : typ.isObject ? isValidObject(typ.cls, val)
                            : isValidPrimitive(typ, val);
    }
    function isValidPrimitive(typ, val) {
        return typeof typ === typeof val;
    }
    function isValidUnion(typs, val) {
        // val must validate against one typ in typs
        return typs.find(function (typ) { return isValid(typ, val); }) !== undefined;
    }
    function isValidEnum(enumName, val) {
        var cases = typeMap[enumName];
        return cases.indexOf(val) !== -1;
    }
    function isValidArray(typ, val) {
        // val must be an array with no invalid elements
        return Array.isArray(val) && val.every(function (element) {
            return isValid(typ, element);
        });
    }
    function isValidMap(typ, val) {
        if (val === null || typeof val !== "object" || Array.isArray(val))
            return false;
        // all values in the map must be typ
        return Object.keys(val).every(function (prop) {
            if (!Object.prototype.hasOwnProperty.call(val, prop))
                return true;
            return isValid(typ, val[prop]);
        });
    }
    function isValidObject(className, val) {
        if (val === null || typeof val !== "object" || Array.isArray(val))
            return false;
        var typeRep = typeMap[className];
        return Object.keys(typeRep).every(function (prop) {
            if (!Object.prototype.hasOwnProperty.call(typeRep, prop))
                return true;
            return isValid(typeRep[prop], val[prop]);
        });
    }
    function A(typ) {
        return { typ: typ, isArray: true };
    }
    function O(className) {
        return { cls: className, isObject: true };
    }
    var typeMap = {
        "PostmanCollection": {
            item: A(O("Item")),
        },
        "Item": {
            name: "",
            response: A(O("Response")),
        },
        "Response": {
            body: "",
        },
    };
})(Convert || (Convert = {}));
